<h1 align="center">FULLHDPORN API</h1> 

<div align="center">
    <a href="https://pepy.tech/project/fullhdporn_api"><img src="https://static.pepy.tech/badge/fullhdporn_api" alt="Downloads"></a>
    <a href="https://github.com/EchterAlsFake/fullhdporn_api/workflows/"><img src="https://github.com/EchterAlsFake/fullhdporn_api/workflows/CodeQL/badge.svg" alt="CodeQL Analysis"/></a>
    <a href="https://github.com/EchterAlsFake/fullhdporn_api/actions/workflows/sync-tests.yml"><img src="https://github.com/EchterAlsFake/fullhdporn_api/actions/workflows/sync-tests.yml/badge.svg" alt="Sync API Tests"/></a>
</div>

# Description
fullhdporn API is an API for fullhdporn.sex. It allows you to fetch information from videos using beautifulsoup and requests.

> [!NOTE]
> This API was made for my Porn Fetch project. If you want additional features,
> open an issue and I will extend this API.

# Disclaimer
> [!IMPORTANT] 
> Fullhdporn API is in violation to the ToS of fullhdporn.sex!
> If you are the website owner of fullhdporn.sex, contact me at my E-Mail, and I'll take this repository immediately offline.
> EchterAlsFake@proton.me

# Quickstart

### Have a look at the [Documentation](https://github.com/EchterAlsFake/API_Docs/blob/master/Porn_APIs/fullhdporn.md) for more details
- Install the library with `pip install fullhdporn_api`


```python
from fullhdporn_api import Client
# Initialize a Client object
client = Client()

# Fetch a video
video_object = client.get_video("<insert_url_here>")

# Information from Video objects
print(video_object.title)
# Download the video
video_object.download(quality="best", path="your_output_path + filename")
# Download speeds can be very slow. This is not my fault, it's the CDN
# SEE DOCUMENTATION FOR MORE
```

# Support (Donations)
I am developing all my projects entirely for free. I do that because I have fun and I don't want
to charge 30€ like other people do.

However, if you find my work useful, please consider donating something. A tiny amount such as 1€
means a lot to me.

Paypal: https://paypal.me/EchterAlsFake
<br>XMR (Monero): `42XwGZYbSxpMvhn9eeP4DwMwZV91tQgAm3UQr6Zwb2wzBf5HcuZCHrsVxa4aV2jhP4gLHsWWELxSoNjfnkt4rMfDDwXy9jR`

# Contribution
Do you see any issues or having some feature requests? Simply open an Issue or talk
in the discussions.

Pull requests are also welcome.

# License
Licensed under the LGPLv3 License
<br>Copyright (C) 2023–2025 Johannes Habel

# Notice
This API is almost fully written by ChatGPT. I don't see a reason to
write the stuff myself when ChatGPT can do the same as I in less
than 20 minutes. It just makes my life easier, but I of course tested
everything, so it's not some AI garbage. This thing actually works :) 